==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/listener/NodePortListenerOverrideFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface NodePortListenerOverrideFluent<A extends NodePortListenerOverrideFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBootstrap instead.
 * @return The buildable object.
 */
@Deprecated public NodePortListenerBootstrapOverride getBootstrap();
    public NodePortListenerBootstrapOverride buildBootstrap();
    public A withBootstrap(NodePortListenerBootstrapOverride bootstrap);
    public Boolean hasBootstrap();
    public NodePortListenerOverrideFluent.BootstrapNested<A> withNewBootstrap();
    public NodePortListenerOverrideFluent.BootstrapNested<A> withNewBootstrapLike(NodePortListenerBootstrapOverride item);
    public NodePortListenerOverrideFluent.BootstrapNested<A> editBootstrap();
    public NodePortListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrap();
    public NodePortListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrapLike(NodePortListenerBootstrapOverride item);
    public A addToBrokers(int index,NodePortListenerBrokerOverride item);
    public A setToBrokers(int index,NodePortListenerBrokerOverride item);
    public A addToBrokers(NodePortListenerBrokerOverride... items);
    public A addAllToBrokers(Collection<NodePortListenerBrokerOverride> items);
    public A removeFromBrokers(NodePortListenerBrokerOverride... items);
    public A removeAllFromBrokers(Collection<NodePortListenerBrokerOverride> items);
    public A removeMatchingFromBrokers(io.fabric8.kubernetes.api.builder.Predicate<NodePortListenerBrokerOverrideBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildBrokers instead.
 * @return The buildable object.
 */
@Deprecated public List<NodePortListenerBrokerOverride> getBrokers();
    public List<NodePortListenerBrokerOverride> buildBrokers();
    public NodePortListenerBrokerOverride buildBroker(int index);
    public NodePortListenerBrokerOverride buildFirstBroker();
    public NodePortListenerBrokerOverride buildLastBroker();
    public NodePortListenerBrokerOverride buildMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<NodePortListenerBrokerOverrideBuilder> predicate);
    public Boolean hasMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<NodePortListenerBrokerOverrideBuilder> predicate);
    public A withBrokers(List<NodePortListenerBrokerOverride> brokers);
    public A withBrokers(NodePortListenerBrokerOverride... brokers);
    public Boolean hasBrokers();
    public NodePortListenerOverrideFluent.BrokersNested<A> addNewBroker();
    public NodePortListenerOverrideFluent.BrokersNested<A> addNewBrokerLike(NodePortListenerBrokerOverride item);
    public NodePortListenerOverrideFluent.BrokersNested<A> setNewBrokerLike(int index,NodePortListenerBrokerOverride item);
    public NodePortListenerOverrideFluent.BrokersNested<A> editBroker(int index);
    public NodePortListenerOverrideFluent.BrokersNested<A> editFirstBroker();
    public NodePortListenerOverrideFluent.BrokersNested<A> editLastBroker();
    public NodePortListenerOverrideFluent.BrokersNested<A> editMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<NodePortListenerBrokerOverrideBuilder> predicate);

    public interface BootstrapNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodePortListenerBootstrapOverrideFluent<NodePortListenerOverrideFluent.BootstrapNested<N>>{

        
    public N and();    public N endBootstrap();
}
    public interface BrokersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodePortListenerBrokerOverrideFluent<NodePortListenerOverrideFluent.BrokersNested<N>>{

        
    public N and();    public N endBroker();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/listener/NodePortListenerOverrideFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface NodePortListenerOverrideFluent<A extends NodePortListenerOverrideFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBootstrap instead.
 * @return The buildable object.
 */
@Deprecated public NodePortListenerBootstrapOverride getBootstrap();
    public NodePortListenerBootstrapOverride buildBootstrap();
    public A withBootstrap(NodePortListenerBootstrapOverride bootstrap);
    public Boolean hasBootstrap();
    public NodePortListenerOverrideFluent.BootstrapNested<A> withNewBootstrap();
    public NodePortListenerOverrideFluent.BootstrapNested<A> withNewBootstrapLike(NodePortListenerBootstrapOverride item);
    public NodePortListenerOverrideFluent.BootstrapNested<A> editBootstrap();
    public NodePortListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrap();
    public NodePortListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrapLike(NodePortListenerBootstrapOverride item);
    public A addToBrokers(int index,NodePortListenerBrokerOverride item);
    public A setToBrokers(int index,NodePortListenerBrokerOverride item);
    public A addToBrokers(NodePortListenerBrokerOverride... items);
    public A addAllToBrokers(Collection<NodePortListenerBrokerOverride> items);
    public A removeFromBrokers(NodePortListenerBrokerOverride... items);
    public A removeAllFromBrokers(Collection<NodePortListenerBrokerOverride> items);
    public A removeMatchingFromBrokers(io.fabric8.kubernetes.api.builder.Predicate<NodePortListenerBrokerOverrideBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildBrokers instead.
 * @return The buildable object.
 */
@Deprecated public java.util.List<NodePortListenerBrokerOverride> getBrokers();
    public java.util.List<NodePortListenerBrokerOverride> buildBrokers();
    public NodePortListenerBrokerOverride buildBroker(int index);
    public NodePortListenerBrokerOverride buildFirstBroker();
    public NodePortListenerBrokerOverride buildLastBroker();
    public NodePortListenerBrokerOverride buildMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<NodePortListenerBrokerOverrideBuilder> predicate);
    public Boolean hasMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<NodePortListenerBrokerOverrideBuilder> predicate);
    public A withBrokers(java.util.List<NodePortListenerBrokerOverride> brokers);
    public A withBrokers(NodePortListenerBrokerOverride... brokers);
    public Boolean hasBrokers();
    public NodePortListenerOverrideFluent.BrokersNested<A> addNewBroker();
    public NodePortListenerOverrideFluent.BrokersNested<A> addNewBrokerLike(NodePortListenerBrokerOverride item);
    public NodePortListenerOverrideFluent.BrokersNested<A> setNewBrokerLike(int index,NodePortListenerBrokerOverride item);
    public NodePortListenerOverrideFluent.BrokersNested<A> editBroker(int index);
    public NodePortListenerOverrideFluent.BrokersNested<A> editFirstBroker();
    public NodePortListenerOverrideFluent.BrokersNested<A> editLastBroker();
    public NodePortListenerOverrideFluent.BrokersNested<A> editMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<NodePortListenerBrokerOverrideBuilder> predicate);

    public interface BootstrapNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodePortListenerBootstrapOverrideFluent<NodePortListenerOverrideFluent.BootstrapNested<N>>{

        
    public N and();    public N endBootstrap();
}
    public interface BrokersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodePortListenerBrokerOverrideFluent<NodePortListenerOverrideFluent.BrokersNested<N>>{

        
    public N and();    public N endBroker();
}


}
